@@ -1,34 +1,28 @@
 /*
  * Copyright (C) 2003 Red Hat, Inc.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
 #include <sys/types.h>
-#ifdef HAVE_SYS_TERMIOS_H
-#include <sys/termios.h>
-#endif
 #include <sys/time.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <signal.h>
 #include <string.h>
-#ifdef HAVE_TERMIOS_H
 #include <termios.h>
-#endif
 #include <unistd.h>
 #include <glib.h>
 #include "caps.hh"
@@ -133,7 +127,7 @@ parse_legacy_mouse_mode(guint8 *data,
                         gsize len)
 {
         int button = 0;
-        const char *shift = "", *control = "", *meta = "";
+        const char *shift = "", *control = "", *alt = "";
         gboolean motion = FALSE;
         int x, y;
         guint8 b;
@@ -168,8 +162,8 @@ parse_legacy_mouse_mode(guint8 *data,
         shift = b & 4 ?
                 "[shift]" :
                 "";
-        meta = b & 8 ?
-                "[meta]" :
+        alt = b & 8 ?
+                "[alt]" :
                 "";
         control = b & 16 ?
                 "[control]" :
@@ -182,7 +176,7 @@ parse_legacy_mouse_mode(guint8 *data,
                 motion ? "motion " : "",
                 (!motion && button) ? "press" : "",
                 (!motion && !button) ? "release" : "",
-                meta, control, shift,
+                alt, control, shift,
                 x, y);
 
         return 6;
@@ -364,17 +358,7 @@ main(int argc, char **argv)
 
 	original = tcattr;
 	signal(SIGINT, sigint_handler);
-	/* Here we approximate what cfmakeraw() would do, for the benefit
-	 * of systems which don't actually provide the function. */
-	tcattr.c_iflag &= ~(IGNBRK | BRKINT | PARMRK | ISTRIP |
-			    INLCR | IGNCR | ICRNL | IXON);
-	tcattr.c_oflag &= ~(OPOST);
-	tcattr.c_lflag &= ~(ECHO | ECHONL | ICANON | ISIG | IEXTEN);
-	tcattr.c_cflag &= ~(CSIZE | PARENB);
-	tcattr.c_cflag |= CS8;
-#ifdef HAVE_CFMAKERAW
 	cfmakeraw(&tcattr);
-#endif
 	if (tcsetattr(STDIN_FILENO, TCSANOW, &tcattr) != 0) {
 		perror("tcsetattr");
 		return 1;
